==> vtours-ttxmlwebservice-1.8.9-08137a.zip: src/Vtours/TTXmlWebService/Service/OfferList/Mapper.php <==
<?php

/**
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

namespace Vtours\TTXmlWebService\Service\OfferList;

## Helper
use Pimcore\Model\Tool;
use Ramsey\Uuid\Uuid;

use Vtours\TTXmlWebService\Model\DatenAngebotRequestModel;
use Vtours\TTXmlWebService\Model\Request\SearchEngineOfferListRQ;
use Vtours\TTXmlWebService\Model\Request\SelectionRequest\HotelSelection;
use Vtours\TTXmlWebService\Model\Request\SelectionRequest\ObjectId;
use Vtours\TTXmlWebService\Model\Request\SelectionRequest\Selection;
use Vtours\TTXmlWebService\Service\MappingHelper\GeneralMappingHelper;

### V2
use Vtours\TTXmlWebService\Model\Request\V2\PackageOffersMainRQ;
use Vtours\TTXmlWebService\Model\Request\V2\PackageOffersRQ\PackageOffersRQ;
use Vtours\TTXmlWebService\Model\Request\V2\RQMeta;
use Vtours\TTXmlWebService\Model\Request\V2\OfferTravellers;


use Vtours\TTXmlWebService\Model\Request\V2\AccommodationOfferMainRQ;
use Vtours\TTXmlWebService\Model\Request\V2\AccommodationOffersRQ\AccommodationOfferRQ;

### V2 offerFilter
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters;
### Filter
#Date Filter ( inbound outbound )
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\DateAndTimeFilter;
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\OutboundTransportDateAndTimeFilter;
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\InboundTransportDateAndTimeFilter;
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\DateRange;
#TravelDuration Filter
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\TravelDurationFilter;
# Price Filter
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\PriceFilter;
## AcommFilter
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\AccomFilter;
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\AccomSelectors;
## Options
use Vtours\TTXmlWebService\Model\Request\V2\OfferOptions;


/**
 * Class Mapper
 *
 * @package Vtours\TTXmlWebService\Service\OfferList
 */
class Mapper
{
    /**
     * @var GeneralMappingHelper $generalMappingHelper
     */
    private $generalMappingHelper;

    public function __construct(GeneralMappingHelper $generalMappingHelper)
    {
        $this->generalMappingHelper = $generalMappingHelper;
    }

    /**
     * @param DatenAngebotRequestModel $request
     *
     * @return SearchEngineOfferListRQ
     */
    public function mapRequestByHotelCode(DatenAngebotRequestModel $request)
    {
        $search = $this->generalMappingHelper->mapSearchEngineRequest($request);

        $selection = new Selection();
        $hotelSelection = new HotelSelection();
        $objectIds = new ObjectId();
        $codeType = $request->getCodeType();
        $code = $request->getCode();

        $objectIds = $objectIds
            ->setType($codeType)
            ->setValue($code);
        $hotelSelection = $hotelSelection->setObjectId($objectIds);
        $selection = $selection->setHotelSelection($hotelSelection);

        $searchEngineOfferListRQ = new SearchEngineOfferListRQ();
        return $searchEngineOfferListRQ
            ->setSelection($selection)
            ->setSearch($search);
    }

    /**
     * @param DatenAngebotRequestModel $request
     * @return PackageOffersMainRQ
     */
    public function mapRequestByHotelCodeV2(DatenAngebotRequestModel $request)
    {
        return ($request->getOffertype()  === 'Package') ? $this->packageOfferRQ($request) : $this->accommodationOfferRQ($request);

    }


    /**
     * @param $request
     * @return AccommodationOfferMainRQ
     * @throws \Exception
     */
    private function accommodationOfferRQ($request)
    {
        $accommodationOfferRQ = new AccommodationOfferMainRQ();
        $accommodationOfferRequest = new AccommodationOfferRQ();

        // MetaData
        $packageOfferMeta = new RQMeta();
        $packageOfferMeta->setRequestId(UUID::uuid4());
        $packageOfferMeta->setTransactonId(UUID::uuid4());
        $accommodationOfferRequest->setRQMeta($packageOfferMeta);

        //travellers
        $travellersList = [];
        foreach($request->getTravellers() as $key => $value) {
            $travellersList[$key] = ["Age" => $value];
        }

        $travellers = new OfferTravellers();
        $travellers->setTravellerList($travellersList);
        $accommodationOfferRequest->setTravellers($travellers);

        //OfferFilters
        $offerFilters = new OfferFilters();

        //Travel Duration Filter
        $travelDurationFilter = new OfferFilters\TravelDurationFilter();
        $travelDurationFilter->setMinDuration((int)$request->getTraveldurationMin());
        $travelDurationFilter->setMaxDuration((int)$request->getTraveldurationMax());
        $offerFilters->setTravelDurationFilter($travelDurationFilter);

        //Price Filter
        if($request->getPriceMax() !== null) {
            $priceFilter = new PriceFilter();
            $priceFilter->setMaxPrice((int)$request->getPriceMax());
            $offerFilters->setPriceFilter($priceFilter);
        }

        //accomFilter
        $accomFilter = new AccomFilter();
        $accomSelectors = new AccomSelectors();

        switch($request->getCodeType()){
            case 'IFF':
                $accomSelectors->setHotelIffCodes([(int)$request->getCode()]);
                break;
            case 'Giata':
                $accomSelectors->setHotelGiataIDs([(int)$request->getCode()]);
                break;
        }

        $accomFilter->setAccomSelectors($accomSelectors);
        $offerFilters->setAccomFilter($accomFilter);


        //set filter in general request
        $accommodationOfferRequest->setOfferFilters($offerFilters);



        $accommodationOfferRQ->setAccommodationOfferRQ($accommodationOfferRequest);

        return $accommodationOfferRQ;

    }


    /**
     * @throws \Exception
     */
    private function packageOfferRQ($request)
    {
        $packageOffersMainRQ = new PackageOffersMainRQ();
        $packageOffersRequest = new PackageOffersRQ();

        // MetaData
        $packageOfferMeta = new RQMeta();
        $packageOfferMeta->setRequestId(UUID::uuid4());
        $packageOfferMeta->setTransactonId(UUID::uuid4());
        $packageOffersRequest->setRQMeta($packageOfferMeta);


        //travellers
        $travellersList = [];
        foreach($request->getTravellers() as $key => $value) {
            $travellersList[$key] = ["Age" => $value];
        }

        $travellers = new OfferTravellers();
        $travellers->setTravellerList($travellersList);
        $packageOffersRequest->setTravellers($travellers);

        //OfferFilters
        $offerFilters = new OfferFilters();

        //DateAndTimeFilter
        $dateAndTimeFilter = new DateAndTimeFilter();
        $outboundTransportDateAndTimeFilter = new OutboundTransportDateAndTimeFilter();
        $inboundTransportDateAndTimeFilter = new InboundTransportDateAndTimeFilter();

        $dateRange = new DateRange();
        $dateRange->setMinDate((new \DateTime($request->getTraveldateStart()->date))->format('Y-m-d'));
        $outboundTransportDateAndTimeFilter->setDateRange($dateRange);

        $dateRange = new DateRange();
        $dateRange->setMaxDate((new \DateTime($request->getTraveldateEnd()->date))->format('Y-m-d'));
        $inboundTransportDateAndTimeFilter->setDateRange($dateRange);

        $dateAndTimeFilter->setInboundTransportDateAndTimeFilter($inboundTransportDateAndTimeFilter);
        $dateAndTimeFilter->setOutboundTransportDateAndTimeFilter($outboundTransportDateAndTimeFilter);


        $offerFilters->setDateAndTimeFilter($dateAndTimeFilter);

        //StationFilter
        if(!empty($request->getDepartureAirport())) {
            $stationFilter = new OfferFilters\StationFilter();
            $departureStationFilter = new OfferFilters\DepartureStationFilter();
            $departureStationFilter->setStationCodes([$request->getDepartureAirport()]);
            $stationFilter->setDepatureStationFilter($departureStationFilter);
            $offerFilters->setStationFilter($stationFilter);
        }


        //Travel Duration Filter
        $travelDurationFilter = new TravelDurationFilter();
        $travelDurationFilter->setMinDuration((int)$request->getTraveldurationMin());
        $travelDurationFilter->setMaxDuration((int)$request->getTraveldurationMax());
        $offerFilters->setTravelDurationFilter($travelDurationFilter);

        //Price Filter
        if($request->getPriceMax() !== null) {
            $priceFilter = new PriceFilter();
            $priceFilter->setMaxPrice((int)$request->getPriceMax());
            $offerFilters->setPriceFilter($priceFilter);
        }

        //accomFilter
        $accomFilter = new AccomFilter();
        $accomSelectors = new AccomSelectors();
        switch($request->getCodeType()) {
            case 'IFF':
                $accomSelectors->setHotelIffCodes([(int)$request->getCode()]);
                break;
            case 'Giata':
                $accomSelectors->setHotelGiataIDs([(int)$request->getCode()]);
                break;
        }
        $accomFilter->setAccomSelectors($accomSelectors);
        $offerFilters->setAccomFilter($accomFilter);


        //set filter in general request
        $packageOffersRequest->setOfferFilters($offerFilters);

        // set options in general request
        $offerOptions = new OfferOptions();
        $packageOffersRequest->setOfferOptions($offerOptions);


        //map all to the mothership
        $packageOffersMainRQ->setPackageOffersRQ($packageOffersRequest);

        return $packageOffersMainRQ;
    }

}

==> vtours-ttxmlwebservice-1.9.3-94a512.zip: src/Vtours/TTXmlWebService/Service/OfferList/Mapper.php <==
<?php

/**
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

namespace Vtours\TTXmlWebService\Service\OfferList;

## Helper
use Pimcore\Model\Tool;
use Ramsey\Uuid\Uuid;

use Vtours\TTXmlWebService\Model\DatenAngebotRequestModel;
use Vtours\TTXmlWebService\Model\Request\SearchEngineOfferListRQ;
use Vtours\TTXmlWebService\Model\Request\SelectionRequest\HotelSelection;
use Vtours\TTXmlWebService\Model\Request\SelectionRequest\ObjectId;
use Vtours\TTXmlWebService\Model\Request\SelectionRequest\Selection;
use Vtours\TTXmlWebService\Service\MappingHelper\GeneralMappingHelper;

### V2
use Vtours\TTXmlWebService\Model\Request\V2\PackageOffersMainRQ;
use Vtours\TTXmlWebService\Model\Request\V2\PackageOffersRQ\PackageOffersRQ;
use Vtours\TTXmlWebService\Model\Request\V2\RQMeta;
use Vtours\TTXmlWebService\Model\Request\V2\OfferTravellers;


use Vtours\TTXmlWebService\Model\Request\V2\AccommodationOfferMainRQ;
use Vtours\TTXmlWebService\Model\Request\V2\AccommodationOffersRQ\AccommodationOfferRQ;

### V2 offerFilter
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters;
### Filter
#Date Filter ( inbound outbound )
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\DateAndTimeFilter;
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\OutboundTransportDateAndTimeFilter;
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\InboundTransportDateAndTimeFilter;
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\DateRange;
#TravelDuration Filter
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\TravelDurationFilter;
# Price Filter
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\PriceFilter;
## AcommFilter
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\AccomFilter;
use Vtours\TTXmlWebService\Model\Request\V2\OfferFilters\AccomSelectors;
## Options
use Vtours\TTXmlWebService\Model\Request\V2\OfferOptions;


/**
 * Class Mapper
 *
 * @package Vtours\TTXmlWebService\Service\OfferList
 */
class Mapper
{
    /**
     * @var GeneralMappingHelper $generalMappingHelper
     */
    private $generalMappingHelper;

    public function __construct(GeneralMappingHelper $generalMappingHelper)
    {
        $this->generalMappingHelper = $generalMappingHelper;
    }

    /**
     * @param DatenAngebotRequestModel $request
     *
     * @return SearchEngineOfferListRQ
     */
    public function mapRequestByHotelCode(DatenAngebotRequestModel $request)
    {
        $search = $this->generalMappingHelper->mapSearchEngineRequest($request);

        $selection = new Selection();
        $hotelSelection = new HotelSelection();
        $objectIds = new ObjectId();
        $codeType = $request->getCodeType();
        $code = $request->getCode();

        $objectIds = $objectIds
            ->setType($codeType)
            ->setValue($code);
        $hotelSelection = $hotelSelection->setObjectId($objectIds);
        $selection = $selection->setHotelSelection($hotelSelection);

        $searchEngineOfferListRQ = new SearchEngineOfferListRQ();
        return $searchEngineOfferListRQ
            ->setSelection($selection)
            ->setSearch($search);
    }

    /**
     * @param DatenAngebotRequestModel $request
     * @return PackageOffersMainRQ|AccommodationOfferMainRQ
     * @throws \Exception
     */
    public function mapRequestByHotelCodeV2(DatenAngebotRequestModel $request)
    {
        return ($request->getOffertype()  === 'Package') ? $this->packageOfferRQ($request) : $this->accommodationOfferRQ($request);

    }


    /**
     * @param $request
     * @return AccommodationOfferMainRQ
     * @throws \Exception
     */
    private function accommodationOfferRQ($request)
    {
        $accommodationOfferRQ = new AccommodationOfferMainRQ();
        $accommodationOfferRequest = new AccommodationOfferRQ();

        // MetaData
        $packageOfferMeta = new RQMeta();
        $packageOfferMeta->setRequestId(UUID::uuid4());
        $packageOfferMeta->setTransactonId(UUID::uuid4());
        $accommodationOfferRequest->setRQMeta($packageOfferMeta);

        //travellers
        $travellersList = [];
        foreach($request->getTravellers() as $key => $value) {
            $travellersList[$key] = ["Age" => $value];
        }

        $travellers = new OfferTravellers();
        $travellers->setTravellerList($travellersList);
        $accommodationOfferRequest->setTravellers($travellers);

        //OfferFilters
        $offerFilters = new OfferFilters();

        //Travel Duration Filter
        $travelDurationFilter = new OfferFilters\TravelDurationFilter();
        $travelDurationFilter->setMinDuration((int)$request->getTraveldurationMin());
        $travelDurationFilter->setMaxDuration((int)$request->getTraveldurationMax());
        $offerFilters->setTravelDurationFilter($travelDurationFilter);

        //Price Filter
        if($request->getPriceMax() !== null) {
            $priceFilter = new PriceFilter();
            $priceFilter->setMaxPrice((int)$request->getPriceMax());
            $offerFilters->setPriceFilter($priceFilter);
        }

        //accomFilter
        $accomFilter = new AccomFilter();
        $accomSelectors = new AccomSelectors();

        switch($request->getCodeType()){
            case 'IFF':
                $accomSelectors->setHotelIffCodes([(int)$request->getCode()]);
                break;
            case 'Giata':
                $accomSelectors->setHotelGiataIDs([(int)$request->getCode()]);
                break;
            case 'TopRegionID':
                $accomSelectors->setRegionIds([(int)$request->getCode()]);
                break;
            default:
                break;
        }

        $accomFilter->setAccomSelectors($accomSelectors);
        $offerFilters->setAccomFilter($accomFilter);


        //set filter in general request
        $accommodationOfferRequest->setOfferFilters($offerFilters);



        $accommodationOfferRQ->setAccommodationOfferRQ($accommodationOfferRequest);

        return $accommodationOfferRQ;

    }


    /**
     * @throws \Exception
     */
    private function packageOfferRQ($request)
    {
        $packageOffersMainRQ = new PackageOffersMainRQ();
        $packageOffersRequest = new PackageOffersRQ();

        // MetaData
        $packageOfferMeta = new RQMeta();
        $packageOfferMeta->setRequestId(UUID::uuid4());
        $packageOfferMeta->setTransactonId(UUID::uuid4());
        $packageOffersRequest->setRQMeta($packageOfferMeta);


        //travellers
        $travellersList = [];
        foreach($request->getTravellers() as $key => $value) {
            $travellersList[$key] = ["Age" => $value];
        }

        $travellers = new OfferTravellers();
        $travellers->setTravellerList($travellersList);
        $packageOffersRequest->setTravellers($travellers);

        //OfferFilters
        $offerFilters = new OfferFilters();

        //DateAndTimeFilter
        $dateAndTimeFilter = new DateAndTimeFilter();
        $outboundTransportDateAndTimeFilter = new OutboundTransportDateAndTimeFilter();
        $inboundTransportDateAndTimeFilter = new InboundTransportDateAndTimeFilter();

        $dateRange = new DateRange();
        $dateRange->setMinDate((new \DateTime($request->getTraveldateStart()->date))->format('Y-m-d'));
        $outboundTransportDateAndTimeFilter->setDateRange($dateRange);

        $dateRange = new DateRange();
        $dateRange->setMaxDate((new \DateTime($request->getTraveldateEnd()->date))->format('Y-m-d'));
        $inboundTransportDateAndTimeFilter->setDateRange($dateRange);

        $dateAndTimeFilter->setInboundTransportDateAndTimeFilter($inboundTransportDateAndTimeFilter);
        $dateAndTimeFilter->setOutboundTransportDateAndTimeFilter($outboundTransportDateAndTimeFilter);


        $offerFilters->setDateAndTimeFilter($dateAndTimeFilter);

        //StationFilter
        if(!empty($request->getDepartureAirport())) {
            $stationFilter = new OfferFilters\StationFilter();
            $departureStationFilter = new OfferFilters\DepartureStationFilter();
            $departureStationFilter->setStationCodes([$request->getDepartureAirport()]);
            $stationFilter->setDepatureStationFilter($departureStationFilter);
            $offerFilters->setStationFilter($stationFilter);
        }


        //Travel Duration Filter
        $travelDurationFilter = new TravelDurationFilter();
        $travelDurationFilter->setMinDuration((int)$request->getTraveldurationMin());
        $travelDurationFilter->setMaxDuration((int)$request->getTraveldurationMax());
        $offerFilters->setTravelDurationFilter($travelDurationFilter);

        //Price Filter
        if($request->getPriceMax() !== null) {
            $priceFilter = new PriceFilter();
            $priceFilter->setMaxPrice((int)$request->getPriceMax());
            $offerFilters->setPriceFilter($priceFilter);
        }

        //accomFilter
        $accomFilter = new AccomFilter();
        $accomSelectors = new AccomSelectors();
        switch($request->getCodeType()) {
            case 'IFF':
                $accomSelectors->setHotelIffCodes([(int)$request->getCode()]);
                break;
            case 'Giata':
                $accomSelectors->setHotelGiataIDs([(int)$request->getCode()]);
                break;
            case 'TopRegionID':
                $accomSelectors->setRegionIds([(int)$request->getCode()]);
                break;
        }
        $accomFilter->setAccomSelectors($accomSelectors);
        $offerFilters->setAccomFilter($accomFilter);


        //set filter in general request
        $packageOffersRequest->setOfferFilters($offerFilters);

        // set options in general request
        $offerOptions = new OfferOptions();
        $packageOffersRequest->setOfferOptions($offerOptions);


        //map all to the mothership
        $packageOffersMainRQ->setPackageOffersRQ($packageOffersRequest);

        return $packageOffersMainRQ;
    }

}
